import React from 'react'

type Instance = { id: string, timer: any }
type EventCallback = (id: string) => void
type Placements = 'top-left' | 'top-center' | 'top-right' | 'bottom-left' | 'bottom-center' | 'bottom-right'
type Appearances = 'info' | 'warning' | 'success' | 'error'

interface InjectedProps {
  notification: NotificationService
}
interface Options {
  placement?: Placements
  autoDismiss?: boolean
  autoDismissTimeout?: number
  animationTimeOut?: number
  Tag?: React.ComponentType<InstanceOptions>
  onAdd?: EventCallback
  onAdded?: EventCallback
  onRemove?: EventCallback
  onRemoved?: EventCallback
}

interface InstanceOptions extends Options {
  appearance?: Appearances
}

declare class NotificationService {
  notify(content: any, options: InstanceOptions): Instance
  dismiss(instance: Instance): void
}

export function useNotification(): NotificationService
export function withNotification<T extends {}>(Comp: React.ComponentType<T>): React.FC<T & InjectedProps>
export const NotificationConsumer: React.ExoticComponent<React.ConsumerProps<InjectedProps>>
export class NotificationProvider extends React.Component<Options>{ }